@@ -13,7 +13,7 @@ class NetworkError(Exception):
 class Cache(objects.Object):
 	def __init__(self, path=None):
 		if path == None: path = f"{HOME}/.cache/"
-		if not os.path.exists(path): os.mkdir(path)
+		if not gfp.exists(path): os.mkdir(path)
 		objects.Object.__init__(self)
 		self.assign({
 			"path":path,
@@ -23,8 +23,8 @@ class Cache(objects.Object):
 			data_path = f"{self.path}/{group}"
 		else:
 			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
-		base = Formats.FilePath(data_path).base()
-		if not os.path.exists(base): os.system(f"mkdir -p {base}")
+		base = FilePath(data_path).base()
+		if not gfp.exists(base): os.system(f"mkdir -p {base}")
 		if format in [str, "str", "string", int, float, "int", "integer", "float", "double"]:
 			Files.save(data_path, str(data), format="str")
 		elif format in [dict, list, "dict", "dictionary", "list", "array", "json"]:
@@ -36,8 +36,8 @@ class Cache(objects.Object):
 			data_path = f"{self.path}/{group}"
 		else:
 			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
-		base = Formats.FilePath(data_path).base()
-		if not os.path.exists(base): os.system(f"mkdir -p {base}")
+		base = FilePath(data_path).base()
+		if not gfp.exists(base): os.system(f"mkdir -p {base}")
 		def load():
 			if format in [str, "str", "string"]:
 				return Files.load(data_path, format="str")
@@ -179,7 +179,7 @@ class WebServer(objects.Thread):
 		app.run(host=self.host, port=self.port)
 	def token(self):
 		if random.randrange(1, 100) <= 5: 
-			self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
+			self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
 		return self.__cache__.get(group=self.id, id="token")
 	def running(self, timeout=3):
 		encoded = urllib.parse.urlencode({
@@ -194,7 +194,7 @@ class WebServer(objects.Thread):
 			return False
 	def run(self):
 		self.__cache__.set(group=self.id, id="daemon", data="*running*")
-		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
+		self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
 	def fork(self, timeout=15, sleeptime=1):
