@@ -15,11 +15,11 @@ def __prompt_password__(message="Password: "):
 	
 # init a default response.
 def __default_response__():
-	return {
+	return r3sponse.ResponseObject({
 		"success":False,
 		"error":None,
 		"message":None,
-	}
+	})
 	
 # check parameters.
 def __check_parameter__(parameter=None, name="parameter", empty_value=None, response=None):
